@@ -16,6 +16,9 @@
 
 #include "newresultpage.h"
 
+#include <fileoperationspreferences.h>
+#include <settings.h>
+
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KColorScheme>
@@ -90,6 +93,21 @@ public:
         return mRequester->fileName();
     }
 
+    void setNameFilter(const QString &nameFilter)
+    {
+        mRequester->setNameFilter(nameFilter);
+    }
+
+    QString nameFilter() const
+    {
+        return mRequester->nameFilter();
+    }
+
+    FileNameRequester *requester()
+    {
+        return mRequester;
+    }
+
 Q_SIGNALS:
     void fileNameChanged(const QString &filename);
 
@@ -125,6 +143,9 @@ public:
         setTitle(i18nc("@title", "Sign / Encrypt Files"));
         auto vLay = new QVBoxLayout(this);
         vLay->setContentsMargins(0, 0, 0, 0);
+        if (!Settings{}.cmsEnabled()) {
+            mWidget->setProtocol(GpgME::OpenPGP);
+        }
         mWidget->setSignAsText(i18nc("@option:check on SignEncryptPage",
                                      "&Sign as:"));
         mWidget->setEncryptForMeText(i18nc("@option:check on SignEncryptPage",
@@ -308,7 +329,7 @@ public:
 
 private:
     void createRequesters(QBoxLayout *lay) {
-        static const QMap <int, QString> icons = {
+        static const QMap<int, QString> icons = {
             { SignEncryptFilesWizard::SignatureCMS, QStringLiteral("document-sign") },
             { SignEncryptFilesWizard::SignaturePGP, QStringLiteral("document-sign") },
             { SignEncryptFilesWizard::CombinedPGP,  QStringLiteral("document-edit-sign-encrypt") },
@@ -316,23 +337,50 @@ private:
             { SignEncryptFilesWizard::EncryptedCMS, QStringLiteral("document-encrypt") },
             { SignEncryptFilesWizard::Directory,    QStringLiteral("folder") }
         };
-        static const QMap <int, QString> toolTips = {
-            { SignEncryptFilesWizard::SignatureCMS, i18n("The S/MIME signature.") },
-            { SignEncryptFilesWizard::SignaturePGP, i18n("The signature.") },
-            { SignEncryptFilesWizard::CombinedPGP,  i18n("The signed and encrypted file.") },
-            { SignEncryptFilesWizard::EncryptedPGP, i18n("The encrypted file.") },
-            { SignEncryptFilesWizard::EncryptedCMS, i18n("The S/MIME encrypted file.") },
-            { SignEncryptFilesWizard::Directory,    i18n("Output directory.") }
+        static const QMap<int, QString> toolTips = {
+            { SignEncryptFilesWizard::SignatureCMS, i18n("This is the filename of the S/MIME signature.") },
+            { SignEncryptFilesWizard::SignaturePGP, i18n("This is the filename of the detached OpenPGP signature.") },
+            { SignEncryptFilesWizard::CombinedPGP,  i18n("This is the filename of the OpenPGP-signed and encrypted file.") },
+            { SignEncryptFilesWizard::EncryptedPGP, i18n("This is the filename of the OpenPGP encrypted file.") },
+            { SignEncryptFilesWizard::EncryptedCMS, i18n("This is the filename of the S/MIME encrypted file.") },
+            { SignEncryptFilesWizard::Directory,    i18n("The resulting files are written to this directory.") }
+        };
+        static const QMap<int, QString> accessibleNames = {
+            { SignEncryptFilesWizard::SignatureCMS, i18n("S/MIME signature file") },
+            { SignEncryptFilesWizard::SignaturePGP, i18n("OpenPGP signature file") },
+            { SignEncryptFilesWizard::CombinedPGP,  i18n("OpenPGP signed and encrypted file") },
+            { SignEncryptFilesWizard::EncryptedPGP, i18n("OpenPGP encrypted file") },
+            { SignEncryptFilesWizard::EncryptedCMS, i18n("S/MIME encrypted file") },
+            { SignEncryptFilesWizard::Directory,    i18n("Output directory") }
+        };
+        static const QMap<int, QString> nameFiltersBinary = {
+            { SignEncryptFilesWizard::SignatureCMS, i18n("S/MIME Signatures (*.p7s)") },
+            { SignEncryptFilesWizard::SignaturePGP, i18n("OpenPGP Signatures (*.sig *.pgp)") },
+            { SignEncryptFilesWizard::CombinedPGP,  i18n("OpenPGP Files (*.gpg *.pgp)") },
+            { SignEncryptFilesWizard::EncryptedPGP, i18n("OpenPGP Files (*.gpg *.pgp)") },
+            { SignEncryptFilesWizard::EncryptedCMS, i18n("S/MIME Files (*.p7m)") },
+            { SignEncryptFilesWizard::Directory,    {} }
+        };
+        static const QMap<int, QString> nameFiltersAscii = {
+            { SignEncryptFilesWizard::SignatureCMS, i18n("S/MIME Signatures (*.p7s *.pem)") },
+            { SignEncryptFilesWizard::SignaturePGP, i18n("OpenPGP Signatures (*.asc *.sig)") },
+            { SignEncryptFilesWizard::CombinedPGP,  i18n("OpenPGP Files (*.asc)") },
+            { SignEncryptFilesWizard::EncryptedPGP, i18n("OpenPGP Files (*.asc)") },
+            { SignEncryptFilesWizard::EncryptedCMS, i18n("S/MIME Files (*.p7m *.pem)") },
+            { SignEncryptFilesWizard::Directory,    {} }
         };
 
         if (!mRequesters.empty()) {
             return;
         }
+        const auto &nameFilters = FileOperationsPreferences().addASCIIArmor() ? nameFiltersAscii : nameFiltersBinary;
         for (auto kind : icons.keys()) {
             auto requesterWithIcon = new FileNameRequesterWithIcon{
                 kind == SignEncryptFilesWizard::Directory ? QDir::Dirs : QDir::Files, this};
             requesterWithIcon->setIcon(QIcon::fromTheme(icons[kind]));
             requesterWithIcon->setToolTip(toolTips[kind]);
+            requesterWithIcon->requester()->setAccessibleNameOfLineEdit(accessibleNames[kind]);
+            requesterWithIcon->setNameFilter(nameFilters[kind]);
             lay->addWidget(requesterWithIcon);
 
             connect(requesterWithIcon, &FileNameRequesterWithIcon::fileNameChanged, this,
