@@ -10,6 +10,9 @@
 
 #include <QWidget>
 #include <QVector>
+
+#include <Libkleo/KeyGroup>
+
 #include <gpgme++/key.h>
 
 class QCheckBox;
@@ -18,7 +21,6 @@ class QVBoxLayout;
 namespace Kleo
 {
 class CertificateLineEdit;
-class KeyGroup;
 class KeySelectionCombo;
 class AbstractKeyListModel;
 class UnknownRecipientWidget;
@@ -100,7 +102,7 @@ protected Q_SLOTS:
     void updateOp();
     void recipientsChanged();
     void recpRemovalRequested(CertificateLineEdit *w);
-    void dialogRequested(CertificateLineEdit *w);
+    void certificateSelectionRequested(CertificateLineEdit *w);
 
 protected:
     void loadKeys();
