@@ -37,32 +37,26 @@
 #include <gpgme++/keylistresult.h>
 #include <gpgme++/tofuinfo.h>
 
+#include <QGpgME/Debug>
 #include <QGpgME/Protocol>
 #include <QGpgME/KeyListJob>
 
+#include <QClipboard>
 #include <QDateTime>
 #include <QGridLayout>
 #include <QGroupBox>
+#include <QGuiApplication>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QLocale>
 #include <QMenu>
 #include <QPushButton>
 #include <QSpacerItem>
-#include <QToolButton>
+#include <QStringBuilder>
 #include <QTreeWidget>
 
 #include <set>
 
-#include <gpgme++/gpgmepp_version.h>
-#if GPGMEPP_VERSION >= 0x10E00 // 1.14.0
-# define GPGME_HAS_REMARKS
-#endif
-#if GPGMEPP_VERSION >= 0x10F00 // 1.15.0
-# define GPGME_HAS_WITH_SECRET
-# include <QGpgME/Debug>
-#endif
-
 #define HIDE_ROW(row) \
     ui.row->setVisible(false); \
     ui.row##Lbl->setVisible(false);
@@ -106,6 +100,7 @@ public:
     void keyListDone(const GpgME::KeyListResult &,
                      const std::vector<GpgME::Key> &, const QString &,
                      const GpgME::Error &);
+    void copyFingerprintToClipboard();
 
 private:
     CertificateDetailsWidget *const q;
@@ -131,11 +126,12 @@ private:
         QLabel *expiresLbl;
         QHBoxLayout *horizontalLayout_3;
         QLabel *expires;
-        QToolButton *changeExpirationBtn;
+        QPushButton *changeExpirationBtn;
         QLabel *typeLbl;
         QLabel *type;
         QLabel *fingerprintLbl;
         QLabel *fingerprint;
+        QPushButton *copyFingerprintBtn;
         QLabel *publishingLbl;
         QPushButton *publishing;
         QLabel *smimeIssuerLbl;
@@ -173,10 +169,10 @@ private:
             hboxLayout_1->addWidget(trustChainDetailsBtn);
 
             genRevokeBtn = new QPushButton(i18n("Generate revocation certificate"), parent);
-            genRevokeBtn->setToolTip(u"<html>" +
+            genRevokeBtn->setToolTip(u"<html>" %
                                      i18n("A revocation certificate is a file that serves as a \"kill switch\" to publicly "
                                           "declare that a key shall not anymore be used.  It is not possible "
-                                          "to retract such a revocation certificate once it has been published.") +
+                                          "to retract such a revocation certificate once it has been published.") %
                                      u"</html>");
 
             hboxLayout_1->addWidget(genRevokeBtn);
@@ -196,7 +192,7 @@ private:
             gridLayout->addWidget(validFromLbl, row, 0, 1, 1);
 
             validFrom = new QLabel(groupBox);
-            validFrom->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+            validFrom->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
             gridLayout->addWidget(validFrom, row, 1, 1, 1);
 
@@ -211,15 +207,14 @@ private:
 
             horizontalLayout_3 = new QHBoxLayout();
             expires = new QLabel(groupBox);
-            expires->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+            expires->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
             horizontalLayout_3->addWidget(expires);
 
-            changeExpirationBtn = new QToolButton(groupBox);
-            changeExpirationBtn->setToolTip(i18n("Change"));
+            changeExpirationBtn = new QPushButton(groupBox);
+            changeExpirationBtn->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
             changeExpirationBtn->setIcon(QIcon::fromTheme(QStringLiteral("editor")));
-            changeExpirationBtn->setIconSize(QSize(16, 16));
-            changeExpirationBtn->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+            changeExpirationBtn->setToolTip(i18nc("@info:tooltip", "Change the expiration date"));
 
             horizontalLayout_3->addWidget(changeExpirationBtn);
 
@@ -231,7 +226,7 @@ private:
             gridLayout->addWidget(typeLbl, row, 0, 1, 1);
 
             type = new QLabel(groupBox);
-            type->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+            type->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
             gridLayout->addWidget(type, row, 1, 1, 1);
             row++;
@@ -240,10 +235,21 @@ private:
 
             gridLayout->addWidget(fingerprintLbl, row, 0, 1, 1);
 
-            fingerprint = new QLabel(groupBox);
-            fingerprint->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
+            {
+                auto hbox = new QHBoxLayout;
+                fingerprint = new QLabel{groupBox};
+                fingerprint->setTextInteractionFlags(Qt::TextSelectableByMouse);
+                hbox->addWidget(fingerprint);
+                copyFingerprintBtn = new QPushButton{groupBox};
+                copyFingerprintBtn->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+                copyFingerprintBtn->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
+                copyFingerprintBtn->setToolTip(i18nc("@info:tooltip", "Copy the fingerprint to the clipboard"));
+                copyFingerprintBtn->setVisible(QGuiApplication::clipboard());
+                hbox->addWidget(copyFingerprintBtn);
+                hbox->addStretch();
 
-            gridLayout->addWidget(fingerprint, row, 1, 1, 2);
+                gridLayout->addLayout(hbox, row, 1, 1, 2);
+            }
             row++;
 
             publishingLbl = new QLabel(i18n("Publishing:"), groupBox);
@@ -381,6 +387,8 @@ CertificateDetailsWidget::Private::Private(CertificateDetailsWidget *qq)
             q, [this]() { webOfTrustClicked(); });
     connect(ui.exportBtn, &QPushButton::clicked,
             q, [this]() { exportClicked(); });
+    connect(ui.copyFingerprintBtn, &QPushButton::clicked,
+            q, [this]() { copyFingerprintToClipboard(); });
 
     connect(Kleo::KeyCache::instance().get(), &Kleo::KeyCache::keysMayHaveChanged,
             q, [this]() { keysMayHaveChanged(); });
@@ -492,7 +500,6 @@ void CertificateDetailsWidget::Private::setupCommonProperties()
 
         GpgME::Error err;
         QStringList tagList;
-#ifdef GPGME_HAS_REMARKS
         for (const auto &tag: uid.remarks(Tags::tagKeys(), err)) {
             if (err) {
                 qCWarning(KLEOPATRA_LOG) << "Getting remarks for user id" << uid.id() << "failed:" << err;
@@ -500,7 +507,6 @@ void CertificateDetailsWidget::Private::setupCommonProperties()
             tagList << QString::fromStdString(tag);
         }
         qCDebug(KLEOPATRA_LOG) << "tagList:" << tagList;
-#endif
         const auto tags = tagList.join(QStringLiteral("; "));
         item->setData(3, Qt::DisplayRole, tags);
         item->setData(3, Qt::ToolTipRole, toolTip);
@@ -860,6 +866,13 @@ void CertificateDetailsWidget::Private::smimeLinkActivated(const QString &link)
     qCWarning(KLEOPATRA_LOG) << "Unknown link activated:" << link;
 }
 
+void CertificateDetailsWidget::Private::copyFingerprintToClipboard()
+{
+    if (auto clipboard = QGuiApplication::clipboard()) {
+        clipboard->setText(QString::fromLatin1(key.primaryFingerprint()));
+    }
+}
+
 CertificateDetailsWidget::CertificateDetailsWidget(QWidget *parent)
     : QWidget{parent}
     , d{std::make_unique<Private>(this)}
@@ -911,21 +924,15 @@ void CertificateDetailsWidget::setKey(const GpgME::Key &key)
     auto ctx = QGpgME::Job::context(job);
     ctx->addKeyListMode(GpgME::WithTofu);
     ctx->addKeyListMode(GpgME::SignatureNotations);
-#ifdef GPGME_HAS_WITH_SECRET
     if (key.hasSecret()) {
         ctx->addKeyListMode(GpgME::WithSecret);
     }
-#endif
 
     // Windows QGpgME new style connect problem makes this necessary.
     connect(job, SIGNAL(result(GpgME::KeyListResult,std::vector<GpgME::Key>,QString,GpgME::Error)),
             this, SLOT(keyListDone(GpgME::KeyListResult,std::vector<GpgME::Key>,QString,GpgME::Error)));
 
-#ifdef GPGME_HAS_WITH_SECRET
     job->start(QStringList() << QLatin1String(key.primaryFingerprint()));
-#else
-    job->start(QStringList() << QLatin1String(key.primaryFingerprint()), key.hasSecret());
-#endif
 }
 
 GpgME::Key CertificateDetailsWidget::key() const
